==> dl.php?src=linea21_1_7.zip: linea21/dashboard/help.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage dashboard
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

$dirbox = $dir . "/help";
?>
<div class="headerhelp">
<div class="help">
<a href="#aide-ancre" class="aide-ancre" id="aide-ancre" title="<?php echo _t('help','title');?>"><i class="icon-lifebuoy"></i> <?php echo _t('help','title');?></a>

<?php if ($todo == 'add') {
  ?>
<div id="aide">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('dashboard','add');?></p>
<ul>
	<li><?php echo _t('dashboard','help_add1');?></li>
	<li><?php echo _t('dashboard','help_add2');?></li>
	<li><?php echo _t('dashboard','help_add5');?></li>
	<li><?php echo _t('dashboard','help_add6');?></li>
	<li><?php echo _t('dashboard','help_add3');?></li>
	<li><?php echo _t('dashboard','help_add4');?></li>
</ul>

  <?php }
  if ($todo == 'det') {
    ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('dashboard','det');?></p>
<ul>
	<li><?php echo _t('dashboard','help_det1');?></li>
	<li><?php echo _t('dashboard','help_det2');?></li>
	<li><?php echo _t('dashboard','help_det3');?></li>
	<li><?php echo _t('dashboard','help_det4');?></li>
	<li><?php echo _t('dashboard','help_det5');?></li>

</ul>

    <?php }
    if ($todo == 'mod') {
      ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('dashboard','mod');?></p>
<ul>
	<li><?php echo _t('dashboard','help_mod1');?></li>
	<li><?php echo _t('dashboard','help_mod2');?></li>
	<li><?php echo _t('dashboard','help_mod3');?></li>
	<li><?php echo _t('dashboard','help_mod4');?></li>
	<li><?php echo _t('dashboard','help_mod5');?></li>
	<li><?php echo _t('dashboard','help_mod6');?></li>
</ul>
      <?php }
      if ($todo == 'rap') {
        ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('dashboard','rap');?></p>
<ul>
	<li><?php echo _t('dashboard','help_rap1');?></li>
	<li><?php echo _t('dashboard','help_rap2');?></li>
	<li><?php echo _t('dashboard','help_rap3');?></li>
</ul>
        <?php }

        if ($todo == 'list') {
          ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('dashboard','list');?></p>
<ul>
	<li><?php echo _t('dashboard','help_list1');?></li>
	<li><?php echo _t('dashboard','help_list2');?></li>
	<li><?php echo _t('dashboard','help_list3');?></li>
	<li><?php echo _t('dashboard','help_list4');?></li>
	<li><?php echo _t('dashboard','help_list5');?></li>
	<li><?php echo _t('dashboard','help_list6');?></li>
	<li><?php echo _t('dashboard','help_list7');?></li>
	<li><?php echo _t('dashboard','help_list8');?></li>
</ul>
          <?php }
          if ($todo == 'sup') {
            ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('dashboard','sup');?></p>
<ul>
	<li><?php echo _t('dashboard','help_sup1');?></li>
	<li><?php echo _t('dashboard','help_sup2');?></li>
</ul>
<?php } 
include_once(THEME_ADMIN_PATH."footer_content.php");
?>

==> dl.php?src=linea21_2_0_0.zip: linea21/dashboard/help.php <==
<?php
/**
 * Dashboard module
 * 
 * Provide an online help related to current module
 * 
 * @package linea21\modules\dashboard
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////
?>
<div class="headerhelp">
<div class="help">
<a href="#aide-ancre" class="aide-ancre" id="aide-ancre" title="<?php echo _t('help','title');?>"><i class="icon-lifebuoy"></i> <?php echo _t('help','title');?></a>

<?php if ($todo == 'add') {
  ?>
<div id="aide">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('dashboard','add');?></p>
<ul>
	<li><?php echo _t('dashboard','help_add1');?></li>
	<li><?php echo _t('dashboard','help_add2');?></li>
	<li><?php echo _t('dashboard','help_add5');?></li>
	<li><?php echo _t('dashboard','help_add6');?></li>
	<li><?php echo _t('dashboard','help_add3');?></li>
	<li><?php echo _t('dashboard','help_add4');?></li>
</ul>

  <?php }
  if ($todo == 'det') {
    ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('dashboard','det');?></p>
<ul>
	<li><?php echo _t('dashboard','help_det1');?></li>
	<li><?php echo _t('dashboard','help_det2');?></li>
	<li><?php echo _t('dashboard','help_det3');?></li>
	<li><?php echo _t('dashboard','help_det4');?></li>
	<li><?php echo _t('dashboard','help_det5');?></li>

</ul>

    <?php }
    if ($todo == 'mod') {
      ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('dashboard','mod');?></p>
<ul>
	<li><?php echo _t('dashboard','help_mod1');?></li>
	<li><?php echo _t('dashboard','help_mod2');?></li>
	<li><?php echo _t('dashboard','help_mod3');?></li>
	<li><?php echo _t('dashboard','help_mod4');?></li>
	<li><?php echo _t('dashboard','help_mod5');?></li>
	<li><?php echo _t('dashboard','help_mod6');?></li>
</ul>
      <?php }
      if ($todo == 'rap') {
        ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('dashboard','rap');?></p>
<ul>
	<li><?php echo _t('dashboard','help_rap1');?></li>
	<li><?php echo _t('dashboard','help_rap2');?></li>
	<li><?php echo _t('dashboard','help_rap3');?></li>
</ul>
        <?php }

        if ($todo == 'list') {
          ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('dashboard','list');?></p>
<ul>
	<li><?php echo _t('dashboard','help_list1');?></li>
	<li><?php echo _t('dashboard','help_list2');?></li>
	<li><?php echo _t('dashboard','help_list3');?></li>
	<li><?php echo _t('dashboard','help_list4');?></li>
	<li><?php echo _t('dashboard','help_list5');?></li>
	<li><?php echo _t('dashboard','help_list6');?></li>
	<li><?php echo _t('dashboard','help_list7');?></li>
	<li><?php echo _t('dashboard','help_list8');?></li>
</ul>
          <?php }
          if ($todo == 'sup') {
            ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('dashboard','sup');?></p>
<ul>
	<li><?php echo _t('dashboard','help_sup1');?></li>
	<li><?php echo _t('dashboard','help_sup2');?></li>
</ul>
<?php } ?>
</div> <!-- closing #aide -->
</div> <!-- closing .help -->
</div> <!-- closing ."headerhelp" -->
